{
  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-21.05";
    nixos-unstable.url = "github:NixOS/nixpkgs/nixos-unstable";
    home-manager = {
      url = "github:rycee/home-manager/release-21.05";
      inputs.nixpkgs.follows = "nixpkgs";
    }; 
  };

  outputs = { self, nixpkgs, nixos-unstable, home-manager }:   
  let
    system = "x86_64-linux";

    unstable = import nixos-unstable { 
      inherit system; 
      config.allowUnfree = true; 
    };

    pkgs = import nixpkgs { 
      inherit system; 
      config.allowUnfree = true; 
      overlays = [ (final: prev: { inherit unstable; }) ];
    };
  in {
    nixosConfigurations.architect = nixpkgs.lib.nixosSystem {
      inherit system;

      modules = [ 
        {
          nixpkgs.pkgs = pkgs;
          nix.nixPath = [ 
            "nixpkgs=${nixpkgs}" 
            "unstable=${nixos-unstable}"
          ];
          nix.registry.nixpkgs.flake = nixpkgs;
          nix.registry.unstable.flake = nixos-unstable;
        }

        home-manager.nixosModules.home-manager
        ./hosts/architect/default.nix
      ];
    };

    nixosConfigurations.gAluminum = nixpkgs.lib.nixosSystem {
      inherit system;

      modules = [ 
        {
          nixpkgs.pkgs = pkgs;
          nix.nixPath = [ 
            "nixpkgs=${nixpkgs}" 
            "unstable=${nixos-unstable}"
          ];
          nix.registry.nixpkgs.flake = nixpkgs;
          nix.registry.unstable.flake = nixos-unstable;
        }

        home-manager.nixosModules.home-manager
        ./hosts/gAluminum/default.nix
      ];
    };
  };
}
